@@ -9,11 +9,15 @@ open Sexplib.Sexp
 open Sexplib.Conv
 
 let () =
-  Exn_converter.add ~finalise:false [%extension_constructor Unix.Unix_error] (function
-    | Unix.Unix_error (err, loc, arg) ->
-      let err_str = Unix.error_message err in
-      List [ Atom "Unix.Unix_error"; Atom err_str; Atom loc; Atom arg ]
-    | _ -> assert false)
+  Exn_converter.add
+    ~printexc:false
+    ~finalise:false
+    [%extension_constructor Unix.Unix_error]
+    (function
+      | Unix.Unix_error (err, loc, arg) ->
+        let err_str = Unix.error_message err in
+        List [ Atom "Unix.Unix_error"; Atom err_str; Atom loc; Atom arg ]
+      | _ -> assert false)
 ;;
 
 let linkme = ()
